% NUC Support for non-uniform coarsening/agglomeration method
%
% Files
%   mergeBlocks      - Merge blocks in a partitioning that are smaller than the given limit.
%                      the given limit.
%   mergeBlocks2     - Alternative implementation of Amalgamation 'MERGE' primitive
%                      seeks to uphold the upper bound on the flow
%                      indicator and optionally on the number of cells in a
%                      block.
%   refineBlocks     - Refine blocks for which indicator value exceeds upper limit
%   refineGreedy     - Refine blocks in a partition using a greedy
%                      algorithm that grows a new block inward from the
%                      block boundary, adding one ring of neighbors in each
%                      iteration.
%   refineGreedy2    - Alternative greedy algorithm that may grow only
%                      parts of the neighboring ring to ensure that upper
%                      bound is not violated.
%   refineGreedy3    - Same as refineGreedy2, except that cells are sorted
%                      by increasing numbers of faces shared with cells in
%                      the block
%   refineGreedy4    - Same as refineGreedy2, except that cells are sorted
%                      by difference in flow indicator from that of the
%                      expanding block.
%   refineUniform    - Refine blocks in a partition by uniform partitioning
%   segmentIndicator - Segments a fine grid into blocks according to indicator.
%                      indicator.
%
% Tutorials (in subdirectory "examples")
%   example1         - Discussion of different flow indicators combined
%                      with uniform refinement of high-flow zones or the
%                      NUC algorithm.
%   example2         - Examples of hybrid grids that combined flow adaption
%                      with a regular partition.
%   example3         - Examples of contrained coarsening.
%
%   adaptiveRefinement - Discusses grids that dynamically adapt to an
%                      advancing saturation front.
%   runSPE10_NUC     - The NUC algorithm applied to individual layers of
%                      the SPE10 dataset.
%   simpleNUC        - Discusses the four basic steps of the NUC algorithm.

%{
Copyright 2009, 2010, 2011 SINTEF ICT, Applied Mathematics.

This file is part of The MATLAB Reservoir Simulation Toolbox (MRST).

MRST is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

MRST is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with MRST.  If not, see <http://www.gnu.org/licenses/>.
%}
