MODS = mrstModule;

mrstModule add stokes-brinkman
% Simple upscaling example comparing upscaling using Darcy and
% Stokes-Brinkman
% NB: only works for Cartesian grids


cellDims  = [12, 12  1];
upscaled  = [6, 6, 1];  % number of blocks in the coarse grid

verbose   = true;

%% define grids
G         = cartGrid(cellDims, cellDims);
G         = computeGeometry(G);
G_ups     = cartGrid(upscaled, cellDims);
G_ups     = computeGeometry(G_ups);

p  = partitionUI(G, upscaled);
p  = processPartition  (G, p, 'Verbose', verbose);
CG = generateCoarseGrid(G, p, 'Verbose', verbose);

rock.perm = convertFrom(100 * rand(G.cells.num,1), milli()*darcy());
fluid     = initSingleFluid('mu' ,    1*centi*poise     , ...
                            'rho', 1014*kilogram/meter^3);

%% BC
% fine scale bc:
bc = pside([], G, 'FRONT', 0);
bnd_faces = bc.face;
bc = pside(bc, G, 'BACK',  1*barsa());

% upscaled bc
bc_ups = pside([], G_ups, 'FRONT', 0);
bnd_faces_ups = bc_ups.face;
bc_ups = pside(bc_ups, G_ups, 'BACK', 1*barsa());


%% Set up solution structures

xRef = initResSol( G, 0.0);
xUps = initResSol( G_ups, 0.0);

S  = computeMimeticIP(G, rock, 'Verbose', verbose);
 
%% Compute upscaled perm
rockUps.perm = upscalePerm(G, CG, rock, 'Verbose', verbose, 'S', S);
rockSB.perm = upscalePermSB(G, CG, rock, 'Verbose', verbose);

% plot all permeabilities
figure;
subplot(2,4,[1,5])
   plotCellData(G, log10(rock.perm));axis equal tight off
coaxis = caxis;
title('Fine perm')
subplot(2,4,2)
plotCellData(G_ups, log10(rockUps.perm(:,1)));  axis equal tight off
caxis(coaxis)
subplot(2,4,3)
plotCellData(G_ups,  log10(rockUps.perm(:,2)));  axis equal tight off
caxis(coaxis)
subplot(2,4,4)
plotCellData(G_ups,  log10(rockUps.perm(:,3)));  axis equal tight off
caxis(coaxis)
subplot(2,4,6)
plotCellData(G_ups,  log10(rockSB.perm(:,1)));  axis equal tight off
caxis(coaxis)
subplot(2,4,7)
plotCellData(G_ups,  log10(rockSB.perm(:,2)));  axis equal tight off
caxis(coaxis)
subplot(2,4,8)
plotCellData(G_ups,  log10(rockSB.perm(:,3)));  axis equal tight off
caxis(coaxis)


%% Make upscaled system structures
S_ups   = computeMimeticIP(G_ups, rockUps, 'Verbose', verbose);
S_upsSB = computeMimeticIP(G_ups, rockSB, 'Verbose', verbose);

%% Solve systems
xRef = solveIncompFlow(xRef, G, S, fluid, 'bc', bc, 'Solver', 'hybrid');
xUps = solveIncompFlow(xUps, G_ups, S_ups, fluid, 'bc', bc_ups, ...
                       'Solver', 'hybrid');

xUpsSB = solveIncompFlow(xUps, G_ups, S_upsSB, fluid, 'bc', bc_ups, ...
                         'Solver', 'hybrid');

%% Compare inflow
flux1 = sum(xRef  .flux(bnd_faces));
flux2 = sum(xUps  .flux(bnd_faces_ups));
flux3 = sum(xUpsSB.flux(bnd_faces_ups));

disp(['Sum flux bnd finescale     : ', num2str(flux1)]);
disp(['Sum flux bnd upscaled Darcy: ', num2str(flux2)]);
disp(['Sum flux bnd upscaled SB   : ', num2str(flux3)]);

mrstModule clear
mrstModule('add', MODS{:});
