% Support for units of measurements and unit conversions.
%
% General unit calculation utilities
%   convertFrom   - Convert physical quantity from given unit to equivalent SI.
%   convertTo     - Convert physical quantity from SI to equivalent given unit.
%   getUnitSystem - Define unit conversion factors for input data.
%
% Prefixes
%   centi         - One houndreth prefix.
%   deci          - One tenth prefix.
%   giga          - One billion (milliard) prefix.
%   kilo          - One thousand prefix.
%   mega          - One million prefix.
%   micro         - One millionth prefix.
%   milli         - One thousandth prefix.
%
% Length
%   ft            - Distance of one foot (in units of meters).
%   inch          - Distance of one inch (in units of meters).
%   meter         - Distance of one meter (in units of meters).
%
% Time
%   day           - Give numerical value, in units of seconds, of one day.
%   hour          - Time span of one hour (in units of seconds).
%   minute        - Time span of one minute (in units of seconds).
%   second        - Time span of one second (in units of seconds).
%   year          - Give numerical value, in units of seconds, of one year.
%
% Mass
%   gram          - Mass of one gram, in units of kilogram.
%   kilogram      - Mass of one kilogram, in units of kilogram.
%   pound         - Mass of one avoirdupois pound, in units of kilogram.
%
% Volume
%   gallon        - Compute numerical value, in units of m^3, of one U.S. liquid gallon.
%   stb           - Compute numerical value, in units of m^3, of one standard barrel.
%
% Pressure
%   atm           - Compute numerical value, in units of Pascal, of one atmosphere.
%   barsa         - Compute numerical value, in units of Pascal, of one bar.
%   Pascal        - Compute numerical value, in units of Pascal, of one Pascal.
%   psia          - Compute numerical value, in units of Pascal, of one Psi.
%
% Force
%   dyne          - Compute numerical value, in units of Newton of one dyne.
%   lbf           - Force excerted by a mass of one avoirdupois pound at Tellus equator.
%   Newton        - Force of one Newton, in units of Newton.
%
% Viscosity
%   poise         - Compute numerical value, in units of Pa*s, of one poise (P).
%
% Permeability
%   darcy         - Compute numerical value, in units of m^2, of the Darcy constant.

%{
Copyright 2009, 2010, 2011 SINTEF ICT, Applied Mathematics.

This file is part of The MATLAB Reservoir Simulation Toolbox (MRST).

MRST is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

MRST is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with MRST.  If not, see <http://www.gnu.org/licenses/>.
%}
